uiEditableComboboxText

Function uiEditableComboboxText 

pub unsafe extern "C" fn uiEditableComboboxText(
    c: *mut uiEditableCombobox,
) -> *mut c_char
Returns the text of the editable combo box.

This text is either the text of one of the predefined list items or the text manually entered by the user.

@param c uiEditableCombobox instance. @returns The editable combo box text.\n A NUL terminated UTF-8 string.\n Caller is responsible for freeing the data with uiFreeText(). @memberof uiEditableCombobox