pub unsafe extern "C" fn uiNewPasswordEntry() -> *mut uiEntryExpand description
Creates a new entry suitable for sensitive inputs like passwords.
The entered text is NOT readable by the user but masked as *******.
@returns A new uiEntry instance. @memberof uiEntry @static