pub unsafe extern "C" fn uiOpenFile(
parent: *mut uiWindow,
) -> *mut c_charExpand description
File chooser dialog window to select a single file.
@param parent Parent window.
@returns File path, NULL on cancel.\n
If path is not NULL:\n
TODO: clarify string encoding.
Caller is responsible for freeing the data with uiFreeText().
@note File paths are separated by the underlying OS file path separator.
@ingroup dataEntry dialogWindow