pub unsafe extern "C" fn uiSaveFile(
parent: *mut uiWindow,
) -> *mut c_charExpand description
Save file dialog window.
The user is asked to confirm overwriting existing files, should the chosen file path already exist on the system.
@param parent Parent window.
@returns File path, NULL on cancel.\n
If path is not NULL:\n
TODO: clarify string encoding.
Caller is responsible for freeing the data with uiFreeText().
@note File paths are separated by the underlying OS file path separator.
@ingroup dataEntry dialogWindow