pub unsafe extern "C" fn uiTableColumnSetWidth(
t: *mut uiTable,
column: c_int,
width: c_int,
)Expand description
Sets the table column width.
Setting the width to -1 will restore automatic column sizing matching
either the width of the content or column header (which ever one is bigger).
@note Darwin currently only resizes to the column header width on -1.
@param t uiTable instance.
@param column Column index.
@param width Column width to set in pixels, -1 to restore automatic
column sizing.
@memberof uiTable