pub unsafe extern "C" fn uiTableGetSelection(
t: *mut uiTable,
) -> *mut uiTableSelectionExpand description
Returns the current table selection.
@param t uiTable instance.
@returns The number of selected rows and corresponding row indices.\n
Caller is responsible for freeing the data with uiFreeTableSelection().
@note For empty selections the Rows pointer will be NULL.
@memberof uiTable