uiWindowOnPositionChanged

Function uiWindowOnPositionChanged 

pub unsafe extern "C" fn uiWindowOnPositionChanged(
    w: *mut uiWindow,
    f: Option<unsafe extern "C" fn(sender: *mut uiWindow, senderData: *mut c_void)>,
    data: *mut c_void,
)
Registers a callback for when the window moved.

@param w uiWindow instance. @param f Callback function.\n @p sender Back reference to the instance that triggered the callback.\n @p senderData User data registered with the sender instance.\n @param data User data to be passed to the callback.

@note Only one callback can be registered at a time. @note The callback is not triggered when calling uiWindowSetPosition(). @memberof uiWindow