pub unsafe extern "C" fn uiWindowSetFullscreen(
w: *mut uiWindow,
fullscreen: c_int,
)Expand description
Sets whether or not the window is full screen.
@param w uiWindow instance.
@param fullscreen TRUE to make window full screen, FALSE otherwise.
@note This method is merely a hint and may be ignored by the system.
@memberof uiWindow