pub unsafe extern "C" fn uiWindowSetResizeable(
w: *mut uiWindow,
resizeable: c_int,
)Expand description
Sets whether or not the window is user resizeable.
@param w uiWindow instance.
@param resizeable TRUE to make window resizable, FALSE otherwise.
@note This method is merely a hint and may be ignored by the system.
@memberof uiWindow