#[repr(C)]pub struct uiTableParams {
pub Model: *mut uiTableModel,
pub RowBackgroundColorModelColumn: c_int,
}Fields
Model: *mut uiTableModelModel holding the data to be displayed. This can NOT be NULL.
RowBackgroundColorModelColumn: c_intuiTableModel column that defines background color for each row,
#uiTableValueTypeColor Background color, NULL to use the default
background color for that row.
-1 to use the default background color for all rows.